function out = get_cov_matrix_c(BhvExp,Ns)

  % This function calculates the random error covariance matrix 
  % of the vector c according to Eq. 36. 
  % 
  % !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  % Note, that using this error covariance matrix is NOT recommended 
  % due to its bad representation (see details in Sec. 5.4).
  % !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  %
  % INPUT VARIABLES:
  %
  % BhvExp is the 'true' 2x2 covariance matrix
  % Ns is the number of spectra averaged non-coherently
  %
  % OUTPUT:
  %
  % out is 4x4 error covariance matrix
  % EXAMPLE:
  %
  % BhvExp(1,1) = 2; % B_{hh}
  % BhvExp(2,2) = 1; % B_{vv}
  % BhvExp(1,2) = 0.5 + 1i*0.1; % R_{hv} + 1i*J_{hv}
  % BhvExp(2,1) = conj(BhvExp(1,2));
  %
  % Ns = 10;
  %
  % get_cov_matrix_c(BhvExp,Ns)
  %
  % The output of the code is as follows:
  %
  %  0.4000    0.3480    0.0314   -0.0000
  %  0.3480    0.6960         0         0
  %  0.0314   -0.0000    0.0378   -0.0000
  % -0.0000    0.0000   -0.0000    0.3346
  
  J   = get_covariance_matrix_zdr_rho_phi(BhvExp);
  CM  = get_cov_matrix_hv(BhvExp,Ns);
  out = J * CM * J';
  
end